Contributing and developing — OpenTAXII 0.1.6 documentation

# Contributing and developing

## Reporting issues

OpenTAXII uses Github’s issue tracker. See the OpenTAXII project page on Github.

## Obtaining the source code

The OpenTAXII source code can be found on Github. See the OpenTAXII project page.

## Layout

OpenTAXII repository has the following layout:

- `docker/` - Docker configuration files (OpenTAXII Docker documentation);
- `docs/` - used to build the documentation;
- `examples/` - configuration and code examples;
- `opentaxii/` - OpenTAXII source;
- `tests/` - opentaxii tests.

## Compiling from source

After cloning the Github repo, just run this:

    (venv) $ python setup.py install

## Running the tests

Almost all OpenTAXII code is covered by the unit tests. OpenTAXII uses py.test and tox for running tests. Type `tox -r` or `py.test` to run the unit tests.

## Generating the documentation

The documentation is written in ReStructuredText (reST) format and processed using Sphinx. To build HTML documentation, go to `docs` and type `make html`.

Next steps

Continue to License.